@@ -5,9 +5,9 @@
 #include <caml/unixsupport.h>
 #include <caml/bigarray.h>
 
-#if defined(__linux)
+#if defined(__linux) || defined(__GNU__)
 # include <errno.h>
-// on Linux, we use getrandom and loop
+// on Linux and GNU/Hurd, we use getrandom and loop
 
 # if __GLIBC__ && __GLIBC__ <= 2 && __GLIBC_MINOR__ < 25
 # include <sys/syscall.h>
@@ -18,15 +18,18 @@
 # endif
 
 void raw_getrandom (uint8_t *data, uint32_t len) {
-  int r, off = 0;
+  size_t off = 0;
+  ssize_t r = 0;
   while (off < len) {
     r = getrandom(data + off, len - off, 0);
-    if (r < 0 && errno == EINTR) continue;
-    else if (r < 0) uerror("getrandom", Nothing);
-    off += r;
+    if (r == -1) {
+      if (errno == EINTR) continue;
+      else uerror("getrandom", Nothing);
+    }
+    off += (size_t)r;
   }
 }
-#elif (defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__OpenBSD__) || defined(__APPLE__))
+#elif (defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)  || defined(__OpenBSD__) || defined(__APPLE__))
 // on BSD and macOS, loop (in pieces of 256) getentropy
 #if defined(__APPLE__)
 // on macOS, getentropy is defined in sys/random.h (on BSD in unistd.h)
@@ -35,10 +38,10 @@ void raw_getrandom (uint8_t *data, uint32_t len) {
 #include <sys/param.h>
 
 void raw_getrandom (uint8_t *data, uint32_t len) {
-  int rlen = 0;
-  for (int i = 0; i <= len; i += 256) {
+  size_t rlen = 0;
+  for (uint32_t i = 0; i <= len; i += 256) {
     rlen = MIN(256, len - i);
-    if (getentropy(data + i, rlen) < 0) uerror("getentropy", Nothing);
+    if (getentropy(data + i, rlen) == -1) uerror("getentropy", Nothing);
   }
 }
 #elif (defined(_WIN32))
